@@ -22,20 +22,25 @@ class CheckFileEndingAction(Action):
 
 
 if __name__ == '__main__':
-
-    arg_parser = ArgumentParser(prog=sys.argv[0], formatter_class=RawDescriptionHelpFormatter,
-                                description='''Script to disassemble EIS1600 file(s) into MIU file(s).
+    arg_parser = ArgumentParser(
+        prog=sys.argv[0], formatter_class=RawDescriptionHelpFormatter,
+        description='''Script to disassemble EIS1600 file(s) into MIU file(s).
 -----
 Give a single EIS1600 file as input
 or 
 Use -e <EIS1600_repo> to batch process all EIS1600 files in the EIS1600 directory.
-''')
+'''
+        )
     arg_parser.add_argument('-v', '--verbose', action='store_true')
-    arg_parser.add_argument('-e', '--eis1600_repo', type=str,
-                            help='Takes a path to the EIS1600 file repo and batch processes all files')
-    arg_parser.add_argument('input', type=str, nargs='?',
-                            help='EIS1600 file to process',
-                            action=CheckFileEndingAction)
+    arg_parser.add_argument(
+        '-e', '--eis1600_repo', type=str,
+        help='Takes a path to the EIS1600 file repo and batch processes all files'
+        )
+    arg_parser.add_argument(
+        'input', type=str, nargs='?',
+        help='EIS1600 file to process',
+        action=CheckFileEndingAction
+        )
     args = arg_parser.parse_args()
 
     verbose = args.verbose
@@ -49,8 +54,7 @@ Use -e <EIS1600_repo> to batch process all EIS1600 files in the EIS1600 director
             input_dir += '/'
 
         print(f'Disassemble EIS1600 files from the EIS1600 repo')
-        files_list = [file for file, checked in read_files_from_readme(input_dir, '# Texts converted into `.EIS1600`\n')
-                      if checked]
+        files_list = read_files_from_readme(input_dir, '# Texts converted into `.EIS1600`\n')
         files_list_done = read_files_from_readme(input_dir, '# Texts disassembled into MIU files\n')
         files_list = [file for file in files_list if file not in files_list_done]
         infiles = get_files_from_eis1600_dir(input_dir, files_list, '*.EIS1600')
@@ -66,7 +70,7 @@ Use -e <EIS1600_repo> to batch process all EIS1600 files in the EIS1600 director
         write_to_readme(input_dir, infiles, '# Texts disassembled into MIU files\n')
     else:
         print(
-            'Pass in a <uri.EIS1600> file to process a single file or use the -e option for batch processing'
+                'Pass in a <uri.EIS1600> file to process a single file or use the -e option for batch processing'
         )
         sys.exit()
 
